@@ -12,33 +12,24 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from oslo_log import log
+from oslo_config import cfg
 
 from ceilometer.agent import plugin_base as plugin
+from ceilometer.openstack.common import log
 
 LOG = log.getLogger(__name__)
 
+cfg.CONF.import_group('service_credentials', 'ceilometer.service')
+
 
 class TenantDiscovery(plugin.DiscoveryBase):
     """Discovery that supplies keystone tenants.
 
     This discovery should be used when the pollster's work can't be divided
-    into smaller pieces than per-tenants. Example of this is the Swift
-    pollster, which polls account details and does so per-project.
+    into smaller pieces than per-tenant. Example of this is the Swift
+    pollster, which polls account details and does so per-tenant.
     """
 
     def discover(self, manager, param=None):
-        domains = manager.keystone.domains.list()
-        LOG.debug('Found %s keystone domains', len(domains))
-        if domains:
-            tenants = []
-            for domain in domains:
-                domain_tenants = manager.keystone.projects.list(domain)
-                LOG.debug("Found %s tenants in domain %s", len(domain_tenants),
-                          domain.name)
-                tenants = tenants + domain_tenants
-        else:
-            tenants = manager.keystone.projects.list()
-            LOG.debug("No domains - found %s tenants in default domain",
-                      len(tenants))
+        tenants = manager.keystone.tenants.list()
         return tenants or []
