@@ -19,7 +19,7 @@
 import itertools
 
 from ceilometer.alarm import evaluator
-from ceilometer.openstack.common.gettextutils import _
+from ceilometer.i18n import _
 from ceilometer.openstack.common import log
 
 LOG = log.getLogger(__name__)
