@@ -15,12 +15,16 @@
 """Rest alarm notifier with trusted authentication."""
 
 from keystoneclient.v3 import client as keystone_client
-from oslo.config import cfg
+from oslo_config import cfg
 from six.moves.urllib import parse
 
 from ceilometer.alarm.notifier import rest
 
 
+cfg.CONF.import_opt('http_timeout', 'ceilometer.service')
+cfg.CONF.import_group('service_credentials', 'ceilometer.service')
+
+
 class TrustRestAlarmNotifier(rest.RestAlarmNotifier):
     """Notifier supporting keystone trust authentication.
 
@@ -32,7 +36,8 @@ class TrustRestAlarmNotifier(rest.RestAlarmNotifier):
     """
 
     @staticmethod
-    def notify(action, alarm_id, previous, current, reason, reason_data):
+    def notify(action, alarm_id, alarm_name, severity, previous, current,
+               reason, reason_data):
         trust_id = action.username
 
         auth_url = cfg.CONF.service_credentials.os_auth_url.replace(
@@ -44,6 +49,7 @@ class TrustRestAlarmNotifier(rest.RestAlarmNotifier):
             auth_url=auth_url,
             region_name=cfg.CONF.service_credentials.os_region_name,
             insecure=cfg.CONF.service_credentials.insecure,
+            timeout=cfg.CONF.http_timeout,
             trust_id=trust_id)
 
         # Remove the fake user
@@ -56,4 +62,5 @@ class TrustRestAlarmNotifier(rest.RestAlarmNotifier):
 
         headers = {'X-Auth-Token': client.auth_token}
         rest.RestAlarmNotifier.notify(
-            action, alarm_id, previous, current, reason, reason_data, headers)
+            action, alarm_id, alarm_name, severity, previous, current, reason,
+            reason_data, headers)
