@@ -80,10 +80,11 @@ class Connection(base.Connection):
         self.db.alarm_history.insert(alarm_change.copy())
 
     def get_alarms(self, name=None, user=None, state=None, meter=None,
-                   project=None, enabled=None, alarm_id=None, pagination=None):
-        """Yields a lists of alarms that match filters
+                   project=None, enabled=None, alarm_id=None, pagination=None,
+                   alarm_type=None, severity=None):
+        """Yields a lists of alarms that match filters.
 
-        :param name: The Alarm name.
+        :param name: Optional name for alarm.
         :param user: Optional ID for user that owns the resource.
         :param state: Optional string for alarm state.
         :param meter: Optional string for alarms associated with meter.
@@ -91,6 +92,8 @@ class Connection(base.Connection):
         :param enabled: Optional boolean to list disable alarm.
         :param alarm_id: Optional alarm_id to return one alarm.
         :param pagination: Optional pagination query.
+        :param alarm_type: Optional alarm type.
+        :param severity: Optional alarm severity.
         """
         if pagination:
             raise ceilometer.NotImplementedError('Pagination not implemented')
@@ -110,13 +113,21 @@ class Connection(base.Connection):
             q['state'] = state
         if meter is not None:
             q['rule.meter_name'] = meter
+        if alarm_type is not None:
+            q['type'] = alarm_type
+        if severity is not None:
+            q['severity'] = severity
 
-        return self._retrieve_alarms(q, [], None)
+        return self._retrieve_alarms(q,
+                                     [("timestamp",
+                                       pymongo.DESCENDING)],
+                                     None)
 
     def get_alarm_changes(self, alarm_id, on_behalf_of,
-                          user=None, project=None, type=None,
-                          start_timestamp=None, start_timestamp_op=None,
-                          end_timestamp=None, end_timestamp_op=None):
+                          user=None, project=None, alarm_type=None,
+                          severity=None, start_timestamp=None,
+                          start_timestamp_op=None, end_timestamp=None,
+                          end_timestamp_op=None):
         """Yields list of AlarmChanges describing alarm history
 
         Changes are always sorted in reverse order of occurrence, given
@@ -134,7 +145,8 @@ class Connection(base.Connection):
                              administrative user, indicating all projects)
         :param user: Optional ID of user to return changes for
         :param project: Optional ID of project to return changes for
-        :project type: Optional change type
+        :param alarm_type: Optional change type
+        :param severity: Optional change severity
         :param start_timestamp: Optional modified timestamp start range
         :param start_timestamp_op: Optional timestamp start range operation
         :param end_timestamp: Optional modified timestamp end range
@@ -147,8 +159,10 @@ class Connection(base.Connection):
             q['user_id'] = user
         if project is not None:
             q['project_id'] = project
-        if type is not None:
-            q['type'] = type
+        if alarm_type is not None:
+            q['type'] = alarm_type
+        if severity is not None:
+            q['severity'] = severity
         if start_timestamp or end_timestamp:
             ts_range = pymongo_utils.make_timestamp_range(start_timestamp,
                                                           end_timestamp,
