@@ -1,8 +1,6 @@
 #
 # Copyright 2012 New Dream Network, LLC (DreamHost)
 #
-# Author: Doug Hellmann <doug.hellmann@dreamhost.com>
-#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -17,42 +15,42 @@
 
 import logging
 import os
-import socket
-from wsgiref import simple_server
 
-import netaddr
-from oslo.config import cfg
+
+from oslo_config import cfg
 from paste import deploy
 import pecan
+from werkzeug import serving
 
 from ceilometer.api import config as api_config
 from ceilometer.api import hooks
 from ceilometer.api import middleware
+from ceilometer.i18n import _
+from ceilometer.i18n import _LW
 from ceilometer.openstack.common import log
-from ceilometer import storage
+from ceilometer import service
 
 LOG = log.getLogger(__name__)
 
 CONF = cfg.CONF
-CONF.import_opt('debug', 'ceilometer.openstack.common.log')
 
-auth_opts = [
+OPTS = [
     cfg.StrOpt('api_paste_config',
                default="api_paste.ini",
                help="Configuration file for WSGI definition of API."
                ),
+    cfg.IntOpt('api_workers', default=1,
+               help='Number of workers for Ceilometer API server.'),
 ]
 
-api_opts = [
+API_OPTS = [
     cfg.BoolOpt('pecan_debug',
-                default=CONF.debug,
-                help='Toggle Pecan Debug Middleware. '
-                'Defaults to global debug value.'
-                ),
+                default=False,
+                help='Toggle Pecan Debug Middleware.'),
 ]
 
-CONF.register_opts(auth_opts)
-CONF.register_opts(api_opts, group='api')
+CONF.register_opts(OPTS)
+CONF.register_opts(API_OPTS, group='api')
 
 
 def get_pecan_config():
@@ -64,9 +62,7 @@ def get_pecan_config():
 def setup_app(pecan_config=None, extra_hooks=None):
     # FIXME: Replace DBHook with a hooks.TransactionHook
     app_hooks = [hooks.ConfigHook(),
-                 hooks.DBHook(
-                     storage.get_connection_from_config(cfg.CONF, 'metering'),
-                     storage.get_connection_from_config(cfg.CONF, 'alarm'),),
+                 hooks.DBHook(),
                  hooks.PipelineHook(),
                  hooks.TranslationHook()]
     if extra_hooks:
@@ -77,11 +73,16 @@ def setup_app(pecan_config=None, extra_hooks=None):
 
     pecan.configuration.set_config(dict(pecan_config), overwrite=True)
 
+    # NOTE(sileht): pecan debug won't work in multi-process environment
+    pecan_debug = CONF.api.pecan_debug
+    if service.get_workers('api') != 1 and pecan_debug:
+        pecan_debug = False
+        LOG.warning(_LW('pecan_debug cannot be enabled, if workers is > 1, '
+                        'the value is overrided with False'))
+
     app = pecan.make_app(
         pecan_config.app.root,
-        static_root=pecan_config.app.static_root,
-        template_path=pecan_config.app.template_path,
-        debug=CONF.api.pecan_debug,
+        debug=pecan_debug,
         force_canonical=getattr(pecan_config.app, 'force_canonical', True),
         hooks=app_hooks,
         wrap_app=middleware.ParsableErrorMiddleware,
@@ -94,7 +95,6 @@ def setup_app(pecan_config=None, extra_hooks=None):
 class VersionSelectorApplication(object):
     def __init__(self):
         pc = get_pecan_config()
-        pc.app.debug = CONF.api.pecan_debug
 
         def not_found(environ, start_response):
             start_response('404 Not Found', [])
@@ -109,35 +109,6 @@ class VersionSelectorApplication(object):
         return self.v2(environ, start_response)
 
 
-def get_server_cls(host):
-    """Return an appropriate WSGI server class base on provided host
-
-    :param host: The listen host for the ceilometer API server.
-    """
-    server_cls = simple_server.WSGIServer
-    if netaddr.valid_ipv6(host):
-        # NOTE(dzyu) make sure use IPv6 sockets if host is in IPv6 pattern
-        if getattr(server_cls, 'address_family') == socket.AF_INET:
-            class server_cls(server_cls):
-                address_family = socket.AF_INET6
-    return server_cls
-
-
-def get_handler_cls():
-    cls = simple_server.WSGIRequestHandler
-
-    # old-style class doesn't support super
-    class CeilometerHandler(cls, object):
-        def address_string(self):
-            if cfg.CONF.api.enable_reverse_dns_lookup:
-                return super(CeilometerHandler, self).address_string()
-            else:
-                # disable reverse dns lookup, directly return ip address
-                return self.client_address[0]
-
-    return CeilometerHandler
-
-
 def load_app():
     # Build the WSGI app
     cfg_file = None
@@ -157,10 +128,6 @@ def build_server():
     app = load_app()
     # Create the WSGI server and start it
     host, port = cfg.CONF.api.host, cfg.CONF.api.port
-    server_cls = get_server_cls(host)
-
-    srv = simple_server.make_server(host, port, app,
-                                    server_cls, get_handler_cls())
 
     LOG.info(_('Starting server in PID %s') % os.getpid())
     LOG.info(_("Configuration:"))
@@ -174,7 +141,9 @@ def build_server():
         LOG.info(_("serving on http://%(host)s:%(port)s") % (
                  {'host': host, 'port': port}))
 
-    return srv
+    workers = service.get_workers('api')
+    serving.run_simple(cfg.CONF.api.host, cfg.CONF.api.port,
+                       app, processes=workers)
 
 
 def app_factory(global_config, **local_conf):
