@@ -21,8 +21,7 @@
 import base64
 import datetime
 
-from oslo_log import log
-from oslo_utils import strutils
+from oslo_context import context
 from oslo_utils import timeutils
 import pecan
 from pecan import rest
@@ -35,10 +34,9 @@ from ceilometer.api.controllers.v2 import base
 from ceilometer.api.controllers.v2 import utils as v2_utils
 from ceilometer.api import rbac
 from ceilometer.i18n import _
-from ceilometer.publisher import utils as publisher_utils
+from ceilometer.openstack.common import log
 from ceilometer import sample
 from ceilometer import storage
-from ceilometer.storage import base as storage_base
 from ceilometer import utils
 
 LOG = log.getLogger(__name__)
@@ -116,8 +114,8 @@ class OldSample(base.Base):
                    resource_id='bd9431c1-8d69-4ad3-803a-8d4a6b89fd36',
                    project_id='35b17138-b364-4e6a-a131-8f3099c5be68',
                    user_id='efd87807-12d2-4b38-9c70-5f5c2ac427ff',
-                   recorded_at=datetime.datetime(2015, 1, 1, 12, 0, 0, 0),
-                   timestamp=datetime.datetime(2015, 1, 1, 12, 0, 0, 0),
+                   recorded_at=datetime.datetime.utcnow(),
+                   timestamp=datetime.datetime.utcnow(),
                    resource_metadata={'name1': 'value1',
                                       'name2': 'value2'},
                    message_id='5460acce-4fd6-480d-ab18-9735ec7b1996',
@@ -180,12 +178,12 @@ class Statistics(base.Base):
                 self.duration_start and
                 self.duration_start < start_timestamp):
             self.duration_start = start_timestamp
-            LOG.debug('clamping min timestamp to range')
+            LOG.debug(_('clamping min timestamp to range'))
         if (end_timestamp and
                 self.duration_end and
                 self.duration_end > end_timestamp):
             self.duration_end = end_timestamp
-            LOG.debug('clamping max timestamp to range')
+            LOG.debug(_('clamping max timestamp to range'))
 
         # If we got valid timestamps back, compute a duration in seconds.
         #
@@ -234,11 +232,6 @@ class Aggregate(base.Base):
 
     @staticmethod
     def validate(aggregate):
-        valid_agg = (storage_base.Connection.CAPABILITIES.get('statistics', {})
-                     .get('aggregation', {}).get('selectable', {}).keys())
-        if aggregate.func not in valid_agg:
-            msg = _('Invalid aggregation function: %s') % aggregate.func
-            raise base.ClientSideError(msg)
         return aggregate
 
     @classmethod
@@ -289,7 +282,8 @@ class MeterController(rest.RestController):
         rbac.enforce('get_samples', pecan.request)
 
         q = q or []
-        limit = v2_utils.enforce_limit(limit)
+        if limit and limit < 0:
+            raise base.ClientSideError(_("Limit must be positive"))
         kwargs = v2_utils.query_to_kwargs(q, storage.SampleFilter.__init__)
         kwargs['meter'] = self.meter_name
         f = storage.SampleFilter(**kwargs)
@@ -297,20 +291,14 @@ class MeterController(rest.RestController):
                 for e in pecan.request.storage_conn.get_samples(f, limit=limit)
                 ]
 
-    @wsme_pecan.wsexpose([OldSample], str, body=[OldSample], status_code=201)
-    def post(self, direct='', samples=None):
+    @wsme_pecan.wsexpose([OldSample], body=[OldSample], status_code=201)
+    def post(self, samples):
         """Post a list of new Samples to Telemetry.
 
-        :param direct: a flag indicates whether the samples will be posted
-                       directly to storage or not.
         :param samples: a list of samples within the request body.
         """
-        rbac.enforce('create_samples', pecan.request)
 
-        direct = strutils.bool_from_string(direct)
-        if not samples:
-            msg = _('Samples should be included in request body')
-            raise base.ClientSideError(msg)
+        rbac.enforce('create_samples', pecan.request)
 
         now = timeutils.utcnow()
         auth_project = rbac.get_limited_to_project(pecan.request.headers)
@@ -320,6 +308,14 @@ class MeterController(rest.RestController):
 
         published_samples = []
         for s in samples:
+            for p in pecan.request.pipeline_manager.pipelines:
+                if p.support_meter(s.counter_name):
+                    break
+            else:
+                message = _("The metric %s is not supported by metering "
+                            "pipeline configuration.") % s.counter_name
+                raise base.ClientSideError(message, status_code=409)
+
             if self.meter_name != s.counter_name:
                 raise wsme.exc.InvalidInput('counter_name', s.counter_name,
                                             'should be %s' % self.meter_name)
@@ -356,29 +352,18 @@ class MeterController(rest.RestController):
                 resource_metadata=utils.restore_nesting(s.resource_metadata,
                                                         separator='.'),
                 source=s.source)
+            published_samples.append(published_sample)
+
             s.message_id = published_sample.id
 
-            sample_dict = publisher_utils.meter_message_from_counter(
-                published_sample,
-                pecan.request.cfg.publisher.telemetry_secret)
-            if direct:
-                ts = timeutils.parse_isotime(sample_dict['timestamp'])
-                sample_dict['timestamp'] = timeutils.normalize_time(ts)
-                pecan.request.storage_conn.record_metering_data(sample_dict)
-            else:
-                published_samples.append(sample_dict)
-        if not direct:
-            pecan.request.notifier.sample(
-                {'user': def_user_id,
-                 'tenant': def_project_id,
-                 'is_admin': True},
-                'telemetry.api',
-                {'samples': published_samples})
+        with pecan.request.pipeline_manager.publisher(
+                context.get_admin_context()) as publisher:
+            publisher(published_samples)
 
         return samples
 
     @wsme_pecan.wsexpose([Statistics],
-                         [base.Query], [six.text_type], int, [Aggregate])
+                         [base.Query], [unicode], int, [Aggregate])
     def statistics(self, q=None, groupby=None, period=None, aggregate=None):
         """Computes the statistics of the samples in the time range given.
 
@@ -418,6 +403,9 @@ class MeterController(rest.RestController):
         try:
             computed = pecan.request.storage_conn.get_meter_statistics(
                 f, period, g, aggregate)
+            LOG.debug(_('computed value coming from %r'),
+                      pecan.request.storage_conn)
+
             return [Statistics(start_timestamp=start,
                                end_timestamp=end,
                                **c.as_dict())
@@ -459,7 +447,7 @@ class Meter(base.Base):
         meter_id = '%s+%s' % (kwargs['resource_id'], kwargs['name'])
         # meter_id is of type Unicode but base64.encodestring() only accepts
         # strings. See bug #1333177
-        meter_id = base64.b64encode(meter_id.encode('utf-8'))
+        meter_id = base64.encodestring(meter_id.encode('utf-8'))
         kwargs['meter_id'] = meter_id
         super(Meter, self).__init__(**kwargs)
 
@@ -482,13 +470,11 @@ class MetersController(rest.RestController):
     def _lookup(self, meter_name, *remainder):
         return MeterController(meter_name), remainder
 
-    @wsme_pecan.wsexpose([Meter], [base.Query], int, str)
-    def get_all(self, q=None, limit=None, unique=''):
+    @wsme_pecan.wsexpose([Meter], [base.Query])
+    def get_all(self, q=None):
         """Return all known meters, based on the data recorded so far.
 
         :param q: Filter rules for the meters to be returned.
-        :param limit: Maximum number of meters to be returned.
-        :param unique: flag to indicate unique meters to be returned.
         """
 
         rbac.enforce('get_meters', pecan.request)
@@ -496,11 +482,7 @@ class MetersController(rest.RestController):
         q = q or []
 
         # Timestamp field is not supported for Meter queries
-        limit = v2_utils.enforce_limit(limit)
         kwargs = v2_utils.query_to_kwargs(
-            q, pecan.request.storage_conn.get_meters,
-            ['limit'], allow_timestamps=False)
+            q, pecan.request.storage_conn.get_meters, allow_timestamps=False)
         return [Meter.from_db_model(m)
-                for m in pecan.request.storage_conn.get_meters(
-                limit=limit, unique=strutils.bool_from_string(unique),
-                **kwargs)]
+                for m in pecan.request.storage_conn.get_meters(**kwargs)]
