@@ -1,8 +1,6 @@
 #
 # Copyright 2014 Red Hat, Inc
 #
-# Author: Eoghan Glynn <eglynn@redhat.com>
-#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -15,10 +13,10 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from oslo.config import cfg
+from oslo_config import cfg
 
+from ceilometer.agent import plugin_base
 from ceilometer import nova_client
-from ceilometer import plugin
 
 OPTS = [
     cfg.BoolOpt('workload_partitioning',
@@ -29,7 +27,7 @@ OPTS = [
 cfg.CONF.register_opts(OPTS, group='compute')
 
 
-class InstanceDiscovery(plugin.DiscoveryBase):
+class InstanceDiscovery(plugin_base.DiscoveryBase):
     def __init__(self):
         super(InstanceDiscovery, self).__init__()
         self.nova_cli = nova_client.Client()
