@@ -2,9 +2,6 @@
 # Copyright 2012 New Dream Network, LLC (DreamHost)
 # Copyright 2013 eNovance
 #
-# Author: Doug Hellmann <doug.hellmann@dreamhost.com>
-#         Julien Danjou <julien@danjou.info>
-#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -20,8 +17,10 @@
 """
 
 import abc
+
 import six
 
+from ceilometer.agent import plugin_base
 from ceilometer.compute import notifications
 from ceilometer.compute import util
 from ceilometer import sample
@@ -49,7 +48,8 @@ class UserMetadataAwareInstanceNotificationBase(
         """Derive sample from notification payload."""
 
 
-class InstanceScheduled(UserMetadataAwareInstanceNotificationBase):
+class InstanceScheduled(UserMetadataAwareInstanceNotificationBase,
+                        plugin_base.NonMetricNotificationBase):
     event_types = ['scheduler.run_instance.scheduled']
 
     def get_instance_properties(self, message):
@@ -75,7 +75,8 @@ class ComputeInstanceNotificationBase(
     event_types = ['compute.instance.*']
 
 
-class Instance(ComputeInstanceNotificationBase):
+class Instance(ComputeInstanceNotificationBase,
+               plugin_base.NonMetricNotificationBase):
     def get_sample(self, message):
         yield sample.Sample.from_notification(
             name='instance',
@@ -140,7 +141,8 @@ class EphemeralDiskSize(ComputeInstanceNotificationBase):
             message=message)
 
 
-class InstanceFlavor(ComputeInstanceNotificationBase):
+class InstanceFlavor(ComputeInstanceNotificationBase,
+                     plugin_base.NonMetricNotificationBase):
     def get_sample(self, message):
         instance_type = message.get('payload', {}).get('instance_type')
         if instance_type:
