@@ -2,9 +2,6 @@
 # Copyright 2012 eNovance <licensing@enovance.com>
 # Copyright 2012 Red Hat, Inc
 #
-# Author: Julien Danjou <julien@danjou.info>
-# Author: Eoghan Glynn <eglynn@redhat.com>
-#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -16,7 +13,7 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from oslo.utils import timeutils
+from oslo_utils import timeutils
 
 from ceilometer.compute import util as compute_util
 from ceilometer import sample
@@ -36,10 +33,11 @@ INSTANCE_PROPERTIES = [
 
 def _get_metadata_from_object(instance):
     """Return a metadata dictionary for the instance."""
+    instance_type = instance.flavor['name'] if instance.flavor else None
     metadata = {
         'display_name': instance.name,
         'name': getattr(instance, 'OS-EXT-SRV-ATTR:instance_name', u''),
-        'instance_type': (instance.flavor['id'] if instance.flavor else None),
+        'instance_type': instance_type,
         'host': instance.hostId,
         'flavor': instance.flavor,
         'status': instance.status.lower(),
