@@ -15,13 +15,13 @@
 
 """Implementation of Inspector abstraction for VMware vSphere"""
 
-from oslo.config import cfg
-from oslo.utils import units
-from oslo.vmware import api
+from oslo_config import cfg
+from oslo_utils import units
+from oslo_vmware import api
 
 from ceilometer.compute.virt import inspector as virt_inspector
 from ceilometer.compute.virt.vmware import vsphere_operations
-from ceilometer.openstack.common.gettextutils import _
+from ceilometer.i18n import _
 
 
 opt_group = cfg.OptGroup(name='vmware',
@@ -30,26 +30,29 @@ opt_group = cfg.OptGroup(name='vmware',
 OPTS = [
     cfg.StrOpt('host_ip',
                default='',
-               help='IP address of the VMware Vsphere host'),
+               help='IP address of the VMware Vsphere host.'),
+    cfg.IntOpt('host_port',
+               default=443,
+               help='Port of the VMware Vsphere host.'),
     cfg.StrOpt('host_username',
                default='',
-               help='Username of VMware Vsphere'),
+               help='Username of VMware Vsphere.'),
     cfg.StrOpt('host_password',
                default='',
-               help='Password of VMware Vsphere',
+               help='Password of VMware Vsphere.',
                secret=True),
     cfg.IntOpt('api_retry_count',
                default=10,
-               help='Number of times a VMware Vsphere API must be retried'),
+               help='Number of times a VMware Vsphere API may be retried.'),
     cfg.FloatOpt('task_poll_interval',
                  default=0.5,
                  help='Sleep time in seconds for polling an ongoing async '
-                      'task'),
+                      'task.'),
     cfg.StrOpt('wsdl_location',
                help='Optional vim service WSDL location '
                     'e.g http://<server>/vimService.wsdl. '
                     'Optional over-ride to default location for bug '
-                    'work-arounds'),
+                    'work-arounds.'),
 ]
 
 cfg.CONF.register_group(opt_group)
@@ -72,7 +75,8 @@ def get_api_session():
         cfg.CONF.vmware.host_password,
         cfg.CONF.vmware.api_retry_count,
         cfg.CONF.vmware.task_poll_interval,
-        wsdl_loc=cfg.CONF.vmware.wsdl_location)
+        wsdl_loc=cfg.CONF.vmware.wsdl_location,
+        port=cfg.CONF.vmware.host_port)
     return api_session
 
 
