@@ -1,8 +1,6 @@
 #
 # Copyright 2014 Red Hat, Inc.
 #
-# Author: Nejc Saje <nsaje@redhat.com>
-#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -17,10 +15,10 @@
 
 import uuid
 
-from oslo.config import cfg
+from oslo_config import cfg
 import tooz.coordination
 
-from ceilometer.openstack.common.gettextutils import _LE, _LI
+from ceilometer.i18n import _LE, _LI
 from ceilometer.openstack.common import log
 from ceilometer import utils
 
@@ -37,7 +35,12 @@ OPTS = [
     cfg.FloatOpt('heartbeat',
                  default=1.0,
                  help='Number of seconds between heartbeats for distributed '
-                      'coordination (float)')
+                      'coordination.'),
+    cfg.FloatOpt('check_watchers',
+                 default=10.0,
+                 help='Number of seconds between checks to see if group '
+                      'membership has changed')
+
 ]
 cfg.CONF.register_opts(OPTS, group='coordination')
 
@@ -75,6 +78,21 @@ class PartitionCoordinator(object):
                 self._started = False
                 LOG.exception(_LE('Error connecting to coordination backend.'))
 
+    def stop(self):
+        if not self._coordinator:
+            return
+
+        for group in list(self._groups):
+            self.leave_group(group)
+
+        try:
+            self._coordinator.stop()
+        except tooz.coordination.ToozError:
+            LOG.exception(_LE('Error connecting to coordination backend.'))
+        finally:
+            self._coordinator = None
+            self._started = False
+
     def is_active(self):
         return self._coordinator is not None
 
@@ -89,6 +107,15 @@ class PartitionCoordinator(object):
                 LOG.exception(_LE('Error sending a heartbeat to coordination '
                                   'backend.'))
 
+    def watch_group(self, namespace, callback):
+        if self._coordinator:
+            self._coordinator.watch_join_group(namespace, callback)
+            self._coordinator.watch_leave_group(namespace, callback)
+
+    def run_watchers(self):
+        if self._coordinator:
+            self._coordinator.run_watchers()
+
     def join_group(self, group_id):
         if not self._coordinator or not self._started or not group_id:
             return
@@ -106,8 +133,19 @@ class PartitionCoordinator(object):
                     create_grp_req.get()
                 except tooz.coordination.GroupAlreadyExist:
                     pass
+            except tooz.coordination.ToozError:
+                LOG.exception(_LE('Error joining partitioning group %s,'
+                                  ' re-trying'), group_id)
         self._groups.add(group_id)
 
+    def leave_group(self, group_id):
+        if group_id not in self._groups:
+            return
+        if self._coordinator:
+            self._coordinator.leave_group(group_id)
+            self._groups.remove(group_id)
+            LOG.info(_LI('Left partitioning group %s'), group_id)
+
     def _get_members(self, group_id):
         if not self._coordinator:
             return [self._my_id]
