@@ -13,10 +13,10 @@
 """MongoDB storage backend"""
 
 from oslo_config import cfg
-from oslo_log import log
 import pymongo
 
 from ceilometer.event.storage import pymongo_base
+from ceilometer.openstack.common import log
 from ceilometer import storage
 from ceilometer.storage import impl_mongodb
 from ceilometer.storage.mongo import utils as pymongo_utils
@@ -57,13 +57,6 @@ class Connection(pymongo_base.Connection):
         if 'event' not in self.db.conn.collection_names():
             self.db.conn.create_collection('event')
         # Establish indexes
-        # NOTE(idegtiarov): This indexes cover get_events, get_event_types, and
-        # get_trait_types requests based on event_type and timestamp fields.
-        self.db.event.create_index(
-            [('event_type', pymongo.ASCENDING),
-             ('timestamp', pymongo.ASCENDING)],
-            name='event_type_idx'
-        )
         ttl = cfg.CONF.database.event_time_to_live
         impl_mongodb.Connection.update_ttl(ttl, 'event_ttl', 'timestamp',
                                            self.db.event)
