@@ -17,17 +17,16 @@ from __future__ import absolute_import
 import datetime
 import os
 
+from oslo.db import exception as dbexc
+from oslo.db.sqlalchemy import session as db_session
 from oslo_config import cfg
-from oslo_db import exception as dbexc
-from oslo_db.sqlalchemy import session as db_session
-from oslo_log import log
 from oslo_utils import timeutils
 import sqlalchemy as sa
 
 from ceilometer.event.storage import base
 from ceilometer.event.storage import models as api_models
-from ceilometer.i18n import _LE, _LI
-from ceilometer import storage
+from ceilometer.i18n import _, _LI
+from ceilometer.openstack.common import log
 from ceilometer.storage.sqlalchemy import models
 from ceilometer import utils
 
@@ -71,7 +70,7 @@ def _build_trait_query(session, trait_type, key, value, op='eq'):
                'ne': (trait_model.value != value)}
     conditions = [trait_model.key == key, op_dict[op]]
     return (session.query(trait_model.event_id.label('ev_id'))
-            .filter(*conditions))
+            .filter(*conditions), trait_model)
 
 
 class Connection(base.Connection):
@@ -94,25 +93,25 @@ class Connection(base.Connection):
         - TraitInt
           - int trait value
           - { event_id: event -> event.id
-              key: trait name
+              key: trait type
               value: integer value
               }
         - TraitDatetime
-          - datetime trait value
+          - int trait value
           - { event_id: event -> event.id
-              key: trait name
+              key: trait type
               value: datetime value
               }
         - TraitText
-          - text trait value
+          - int trait value
           - { event_id: event -> event.id
-              key: trait name
+              key: trait type
               value: text value
               }
         - TraitFloat
-          - float trait value
+          - int trait value
           - { event_id: event -> event.id
-              key: trait name
+              key: trait type
               value: float value
               }
 
@@ -131,62 +130,52 @@ class Connection(base.Connection):
         # in storage.__init__.get_connection_from_config function
         options = dict(cfg.CONF.database.items())
         options['max_retries'] = 0
-        # oslo.db doesn't support options defined by Ceilometer
-        for opt in storage.OPTS:
-            options.pop(opt.name, None)
         self._engine_facade = db_session.EngineFacade(url, **options)
 
     def upgrade(self):
         # NOTE(gordc): to minimise memory, only import migration when needed
-        from oslo_db.sqlalchemy import migration
+        from oslo.db.sqlalchemy import migration
         path = os.path.join(os.path.abspath(os.path.dirname(__file__)),
                             '..', '..', 'storage', 'sqlalchemy',
                             'migrate_repo')
-        engine = self._engine_facade.get_engine()
-
-        from migrate import exceptions as migrate_exc
-        from migrate.versioning import api
-        from migrate.versioning import repository
-
-        repo = repository.Repository(path)
-        try:
-            api.db_version(engine, repo)
-        except migrate_exc.DatabaseNotControlledError:
-            models.Base.metadata.create_all(engine)
-            api.version_control(engine, repo, repo.latest)
-        else:
-            migration.db_sync(engine, path)
+        migration.db_sync(self._engine_facade.get_engine(), path)
 
     def clear(self):
         engine = self._engine_facade.get_engine()
         for table in reversed(models.Base.metadata.sorted_tables):
             engine.execute(table.delete())
+        self._engine_facade._session_maker.close_all()
         engine.dispose()
 
-    def _get_or_create_event_type(self, event_type, session):
+    def _get_or_create_event_type(self, event_type, session=None):
         """Check if an event type with the supplied name is already exists.
 
         If not, we create it and return the record. This may result in a flush.
         """
-        try:
-            with session.begin(nested=True):
-                et = session.query(models.EventType).filter(
-                    models.EventType.desc == event_type).first()
-                if not et:
-                    et = models.EventType(event_type)
-                    session.add(et)
-        except dbexc.DBDuplicateEntry:
-            et = self._get_or_create_event_type(event_type, session)
-
+        if session is None:
+            session = self._engine_facade.get_session()
+        with session.begin(subtransactions=True):
+            et = session.query(models.EventType).filter(
+                models.EventType.desc == event_type).first()
+            if not et:
+                et = models.EventType(event_type)
+                session.add(et)
         return et
 
     def record_events(self, event_models):
         """Write the events to SQL database via sqlalchemy.
 
         :param event_models: a list of model.Event objects.
+
+        Returns a list of events that could not be saved in a
+        (reason, event) tuple. Reasons are enumerated in
+        storage.model.Event
+
+        Flush when they're all added, unless new EventTypes or
+        TraitTypes are added along the way.
         """
         session = self._engine_facade.get_session()
-        error = None
+        problem_events = []
         for event_model in event_models:
             event = None
             try:
@@ -213,24 +202,29 @@ class Connection(base.Connection):
                             session.execute(model.__table__.insert(),
                                             trait_map[dtype])
             except dbexc.DBDuplicateEntry as e:
-                LOG.info(_LI("Duplicate event detected, skipping it: %s") % e)
+                LOG.exception(_("Failed to record duplicated event: %s") % e)
+                problem_events.append((api_models.Event.DUPLICATE,
+                                       event_model))
             except KeyError as e:
-                LOG.exception(_LE('Failed to record event: %s') % e)
+                LOG.exception(_('Failed to record event: %s') % e)
+                problem_events.append((api_models.Event.INCOMPATIBLE_TRAIT,
+                                       event_model))
             except Exception as e:
-                LOG.exception(_LE('Failed to record event: %s') % e)
-                error = e
-        if error:
-            raise error
+                LOG.exception(_('Failed to record event: %s') % e)
+                problem_events.append((api_models.Event.UNKNOWN_PROBLEM,
+                                       event_model))
+        return problem_events
 
-    def get_events(self, event_filter, limit=None):
+    def get_events(self, event_filter):
         """Return an iterable of model.Event objects.
 
         :param event_filter: EventFilter instance
         """
-        if limit == 0:
-            return
+
         session = self._engine_facade.get_session()
         with session.begin():
+            event_query = session.query(models.Event)
+
             # Build up the join conditions
             event_join_conditions = [models.EventType.id ==
                                      models.Event.event_type_id]
@@ -239,6 +233,9 @@ class Connection(base.Connection):
                 event_join_conditions.append(models.EventType.desc ==
                                              event_filter.event_type)
 
+            event_query = event_query.join(models.EventType,
+                                           sa.and_(*event_join_conditions))
+
             # Build up the where conditions
             event_filter_conditions = []
             if event_filter.message_id:
@@ -250,6 +247,9 @@ class Connection(base.Connection):
             if event_filter.end_timestamp:
                 event_filter_conditions.append(
                     models.Event.generated <= event_filter.end_timestamp)
+            if event_filter_conditions:
+                event_query = (event_query.
+                               filter(sa.and_(*event_filter_conditions)))
 
             trait_subq = None
             # Build trait filter
@@ -258,17 +258,17 @@ class Connection(base.Connection):
                 trait_filter = filters.pop()
                 key = trait_filter.pop('key')
                 op = trait_filter.pop('op', 'eq')
-                trait_type, value = list(trait_filter.items())[0]
-                trait_subq = _build_trait_query(session, trait_type,
-                                                key, value, op)
+                trait_subq, t_model = _build_trait_query(
+                    session, trait_filter.keys()[0], key,
+                    trait_filter.values()[0], op)
                 for trait_filter in filters:
                     key = trait_filter.pop('key')
                     op = trait_filter.pop('op', 'eq')
-                    trait_type, value = list(trait_filter.items())[0]
-                    q = _build_trait_query(session, trait_type,
-                                           key, value, op)
+                    q, model = _build_trait_query(
+                        session, trait_filter.keys()[0], key,
+                        trait_filter.values()[0], op)
                     trait_subq = trait_subq.filter(
-                        trait_subq.subquery().c.ev_id == q.subquery().c.ev_id)
+                        q.filter(model.event_id == t_model.event_id).exists())
                 trait_subq = trait_subq.subquery()
 
             query = (session.query(models.Event.id)
@@ -277,72 +277,56 @@ class Connection(base.Connection):
             if trait_subq is not None:
                 query = query.join(trait_subq,
                                    trait_subq.c.ev_id == models.Event.id)
-            if event_filter.admin_proj:
-                no_proj_q = session.query(models.TraitText.event_id).filter(
-                    models.TraitText.key == 'project_id')
-                admin_q = (session.query(models.TraitText.event_id).filter(
-                    ~sa.exists().where(models.TraitText.event_id ==
-                                       no_proj_q.subquery().c.event_id)).union(
-                    session.query(models.TraitText.event_id).filter(sa.and_(
-                        models.TraitText.key == 'project_id',
-                        models.TraitText.value == event_filter.admin_proj,
-                        models.Event.id == models.TraitText.event_id))))
-                query = query.filter(sa.exists().where(
-                    models.Event.id ==
-                    admin_q.subquery().c.trait_text_event_id))
             if event_filter_conditions:
                 query = query.filter(sa.and_(*event_filter_conditions))
 
-            query = query.order_by(models.Event.generated).limit(limit)
             event_list = {}
             # get a list of all events that match filters
             for (id_, generated, message_id,
                  desc, raw) in query.add_columns(
                      models.Event.generated, models.Event.message_id,
-                     models.EventType.desc, models.Event.raw).all():
+                     models.EventType.desc, models.Event.raw).order_by(
+                         models.Event.generated).all():
                 event_list[id_] = api_models.Event(message_id, desc,
                                                    generated, [], raw)
             # Query all traits related to events.
             # NOTE (gordc): cast is done because pgsql defaults to TEXT when
             #               handling unknown values such as null.
             trait_q = (
-                session.query(
-                    models.TraitDatetime.event_id,
+                query.join(
+                    models.TraitDatetime,
+                    models.TraitDatetime.event_id == models.Event.id)
+                .add_columns(
                     models.TraitDatetime.key, models.TraitDatetime.value,
                     sa.cast(sa.null(), sa.Integer),
                     sa.cast(sa.null(), sa.Float(53)),
                     sa.cast(sa.null(), sa.String(255)))
-                .filter(sa.exists().where(
-                    models.TraitDatetime.event_id == query.subquery().c.id))
-            ).union_all(
-                session.query(
-                    models.TraitInt.event_id,
-                    models.TraitInt.key, sa.null(),
-                    models.TraitInt.value, sa.null(), sa.null())
-                .filter(sa.exists().where(
-                    models.TraitInt.event_id == query.subquery().c.id)),
-                session.query(
-                    models.TraitFloat.event_id,
-                    models.TraitFloat.key, sa.null(), sa.null(),
-                    models.TraitFloat.value, sa.null())
-                .filter(sa.exists().where(
-                    models.TraitFloat.event_id == query.subquery().c.id)),
-                session.query(
-                    models.TraitText.event_id,
-                    models.TraitText.key, sa.null(), sa.null(), sa.null(),
-                    models.TraitText.value)
-                .filter(sa.exists().where(
-                    models.TraitText.event_id == query.subquery().c.id)))
+            ).union(
+                query.join(
+                    models.TraitInt,
+                    models.TraitInt.event_id == models.Event.id)
+                .add_columns(models.TraitInt.key, sa.null(),
+                             models.TraitInt.value, sa.null(), sa.null()),
+                query.join(
+                    models.TraitFloat,
+                    models.TraitFloat.event_id == models.Event.id)
+                .add_columns(models.TraitFloat.key, sa.null(),
+                             sa.null(), models.TraitFloat.value, sa.null()),
+                query.join(
+                    models.TraitText,
+                    models.TraitText.event_id == models.Event.id)
+                .add_columns(models.TraitText.key, sa.null(),
+                             sa.null(), sa.null(), models.TraitText.value))
 
             for id_, key, t_date, t_int, t_float, t_text in (
-                    trait_q.order_by(models.TraitDatetime.key)).all():
-                if t_int is not None:
+                    trait_q.order_by('2')).all():
+                if t_int:
                     dtype = api_models.Trait.INT_TYPE
                     val = t_int
-                elif t_float is not None:
+                elif t_float:
                     dtype = api_models.Trait.FLOAT_TYPE
                     val = t_float
-                elif t_date is not None:
+                elif t_date:
                     dtype = api_models.Trait.DATETIME_TYPE
                     val = t_date
                 else:
@@ -353,11 +337,9 @@ class Connection(base.Connection):
                     trait_model = api_models.Trait(key, dtype, val)
                     event_list[id_].append_trait(trait_model)
                 except KeyError:
-                    # NOTE(gordc): this is expected as we do not set REPEATABLE
-                    # READ (bug 1506717). if query is run while recording new
-                    # event data, trait query may return more data than event
-                    # query. they can be safely discarded.
-                    pass
+                    LOG.warning('Trait key: %(key)s, val: %(val)s, for event: '
+                                '%(event)s not valid.' %
+                                {'key': key, 'val': val, 'event': id_})
 
             return event_list.values()
 
