@@ -1,8 +1,6 @@
 #
 # Copyright 2012 New Dream Network, LLC (DreamHost)
 #
-# Author: Julien Danjou <julien@danjou.info>
-#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -18,13 +16,12 @@
 """
 
 from __future__ import absolute_import
-import itertools
 
 import glanceclient
-from oslo.config import cfg
-from oslo.utils import timeutils
+from oslo_config import cfg
+from oslo_utils import timeutils
 
-from ceilometer.central import plugin
+from ceilometer.agent import plugin_base
 from ceilometer import sample
 
 
@@ -39,17 +36,17 @@ OPTS = [
                     "(default value in glanceclient is used)."),
 ]
 
-service_types_opts = [
+SERVICE_OPTS = [
     cfg.StrOpt('glance',
                default='image',
                help='Glance service type.'),
 ]
 
 cfg.CONF.register_opts(OPTS)
-cfg.CONF.register_opts(service_types_opts, group='service_types')
+cfg.CONF.register_opts(SERVICE_OPTS, group='service_types')
 
 
-class _Base(plugin.CentralPollster):
+class _Base(plugin_base.PollsterBase):
 
     @property
     def default_discovery(self):
@@ -71,30 +68,7 @@ class _Base(plugin.CentralPollster):
         kwargs = {}
         if page_size > 0:
             kwargs['page_size'] = page_size
-        rawImageList = list(itertools.chain(
-            client.images.list(filters={"is_public": True}, **kwargs),
-            # TODO(eglynn): extend glance API with all_tenants logic to
-            #              avoid second call to retrieve private images
-            client.images.list(filters={"is_public": False}, **kwargs)))
-
-        # When retrieving images from glance, glance will check
-        # whether the user is of 'admin_role' which is
-        # configured in glance-api.conf. If the user is of
-        # admin_role, and is querying public images(which means
-        # that the 'is_public' param is set to be True),
-        # glance will ignore 'is_public' parameter and returns
-        # all the public images together with private images.
-        # As a result, if the user/tenant has an admin role
-        # for ceilometer to collect image list,
-        # the _Base.iter_images method will return an image list
-        # which contains duplicate images. Add the following
-        # code to avoid recording down duplicate image events.
-        imageIdSet = set(image.id for image in rawImageList)
-
-        for image in rawImageList:
-            if image.id in imageIdSet:
-                imageIdSet -= set([image.id])
-                yield image
+        return client.images.list(filters={"is_public": None}, **kwargs)
 
     def _iter_images(self, ksclient, cache, endpoint):
         """Iterate over all images."""
