@@ -1,8 +1,6 @@
 #
 # Copyright 2012 New Dream Network, LLC (DreamHost)
 #
-# Author: Julien Danjou <julien@danjou.info>
-#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -19,11 +17,11 @@
 
 """
 
-from oslo.config import cfg
 import oslo.messaging
+from oslo_config import cfg
 
+from ceilometer.agent import plugin_base
 from ceilometer.openstack.common import log
-from ceilometer import plugin
 from ceilometer import sample
 
 OPTS = [
@@ -38,7 +36,7 @@ cfg.CONF.register_opts(OPTS)
 LOG = log.getLogger(__name__)
 
 
-class NetworkNotificationBase(plugin.NotificationBase):
+class NetworkNotificationBase(plugin_base.NotificationBase):
 
     resource_name = None
 
@@ -112,42 +110,43 @@ class NetworkNotificationBase(plugin.NotificationBase):
                     message=resource_message)
 
 
-class Network(NetworkNotificationBase):
+class Network(NetworkNotificationBase, plugin_base.NonMetricNotificationBase):
     """Listen for Neutron network notifications.
 
-    Listen in order to mediate with the metering framework.
+    Handle network.{create.end|update.*|exists} notifications from neutron.
     """
     resource_name = 'network'
 
 
-class Subnet(NetworkNotificationBase):
+class Subnet(NetworkNotificationBase, plugin_base.NonMetricNotificationBase):
     """Listen for Neutron notifications.
 
-    Listen in order to mediate with the metering framework.
+    Handle subnet.{create.end|update.*|exists} notifications from neutron.
     """
     resource_name = 'subnet'
 
 
-class Port(NetworkNotificationBase):
+class Port(NetworkNotificationBase, plugin_base.NonMetricNotificationBase):
     """Listen for Neutron notifications.
 
-    Listen in order to mediate with the metering framework.
+    Handle port.{create.end|update.*|exists} notifications from neutron.
     """
     resource_name = 'port'
 
 
-class Router(NetworkNotificationBase):
+class Router(NetworkNotificationBase, plugin_base.NonMetricNotificationBase):
     """Listen for Neutron notifications.
 
-    Listen in order to mediate with the metering framework.
+    Handle router.{create.end|update.*|exists} notifications from neutron.
     """
     resource_name = 'router'
 
 
-class FloatingIP(NetworkNotificationBase):
+class FloatingIP(NetworkNotificationBase,
+                 plugin_base.NonMetricNotificationBase):
     """Listen for Neutron notifications.
 
-    Listen in order to mediate with the metering framework.
+    Handle floatingip.{create.end|update.*|exists} notifications from neutron.
     """
     resource_name = 'floatingip'
     counter_name = 'ip.floating'
@@ -171,3 +170,113 @@ class Bandwidth(NetworkNotificationBase):
             project_id=message['payload']['tenant_id'],
             resource_id=message['payload']['label_id'],
             message=message)
+
+
+class Pool(NetworkNotificationBase, plugin_base.NonMetricNotificationBase):
+    """Listen for Neutron notifications.
+
+    Handle pool.{create.end|update.*|exists} notifications from neutron.
+    """
+    resource_name = 'pool'
+    counter_name = 'network.services.lb.pool'
+
+
+class Vip(NetworkNotificationBase, plugin_base.NonMetricNotificationBase):
+    """Listen for Neutron notifications.
+
+    Handle vip.{create.end|update.*|exists} notifications from neutron.
+    """
+    resource_name = 'vip'
+    counter_name = 'network.services.lb.vip'
+
+
+class Member(NetworkNotificationBase, plugin_base.NonMetricNotificationBase):
+    """Listen for Neutron notifications.
+
+    Handle member.{create.end|update.*|exists} notifications from neutron.
+    """
+    resource_name = 'member'
+    counter_name = 'network.services.lb.member'
+
+
+class HealthMonitor(NetworkNotificationBase,
+                    plugin_base.NonMetricNotificationBase):
+    """Listen for Neutron notifications.
+
+    Handle health_monitor.{create.end|update.*|exists} notifications
+    from neutron.
+    """
+    resource_name = 'health_monitor'
+    counter_name = 'network.services.lb.health_monitor'
+
+
+class Firewall(NetworkNotificationBase, plugin_base.NonMetricNotificationBase):
+    """Listen for Neutron notifications.
+
+    Handle firewall.{create.end|update.*|exists} notifications from neutron.
+    """
+    resource_name = 'firewall'
+    counter_name = 'network.services.firewall'
+
+
+class FirewallPolicy(NetworkNotificationBase,
+                     plugin_base.NonMetricNotificationBase):
+    """Listen for Neutron notifications.
+
+    Handle firewall_policy.{create.end|update.*|exists} notifications
+    from neutron.
+    """
+    resource_name = 'firewall_policy'
+    counter_name = 'network.services.firewall.policy'
+
+
+class FirewallRule(NetworkNotificationBase,
+                   plugin_base.NonMetricNotificationBase):
+    """Listen for Neutron notifications.
+
+    Handle firewall_rule.{create.end|update.*|exists} notifications
+    from neutron.
+    """
+    resource_name = 'firewall_rule'
+    counter_name = 'network.services.firewall.rule'
+
+
+class VPNService(NetworkNotificationBase,
+                 plugin_base.NonMetricNotificationBase):
+    """Listen for Neutron notifications.
+
+    Handle vpnservice.{create.end|update.*|exists} notifications from neutron.
+    """
+    resource_name = 'vpnservice'
+    counter_name = 'network.services.vpn'
+
+
+class IPSecPolicy(NetworkNotificationBase,
+                  plugin_base.NonMetricNotificationBase):
+    """Listen for Neutron notifications.
+
+    Handle pool.{create.end|update.*|exists} notifications from neutron.
+    """
+    resource_name = 'ipsecpolicy'
+    counter_name = 'network.services.vpn.ipsecpolicy'
+
+
+class IKEPolicy(NetworkNotificationBase,
+                plugin_base.NonMetricNotificationBase):
+    """Listen for Neutron notifications.
+
+    Handle ikepolicy.{create.end|update.*|exists} notifications from neutron.
+    """
+    resource_name = 'ikepolicy'
+    counter_name = 'network.services.vpn.ikepolicy'
+
+
+class IPSecSiteConnection(NetworkNotificationBase,
+                          plugin_base.NonMetricNotificationBase):
+    """Listen for Neutron notifications.
+
+    Handle ipsec_site_connection.{create.end|update.*|exists}
+    notifications from neutron.
+    """
+    resource_name = 'ipsec_site_connection'
+    counter_name = 'network.services.vpn.connections'
