@@ -1,8 +1,6 @@
 #
 # Copyright 2014 Cisco Systems,Inc.
 #
-# Author: Pradeep Kilambi <pkilambi@cisco.com>
-#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -15,9 +13,9 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+from ceilometer.agent import plugin_base
 from ceilometer import neutron_client
 from ceilometer.openstack.common import log
-from ceilometer import plugin
 
 LOG = log.getLogger(__name__)
 
@@ -30,12 +28,13 @@ STATUS = {
 }
 
 
-class BaseServicesPollster(plugin.PollsterBase):
+class BaseServicesPollster(plugin_base.PollsterBase):
 
     FIELDS = []
     nc = neutron_client.Client()
 
-    def _iter_cache(self, cache, meter_name, method):
+    @staticmethod
+    def _iter_cache(cache, meter_name, method):
         if meter_name not in cache:
             cache[meter_name] = list(method())
         return iter(cache[meter_name])
