@@ -1,8 +1,6 @@
 #
 # Copyright (c) 2014 Cisco Systems, Inc
 #
-# Author:Pradeep Kilambi <pkilambi@cisco.com>
-#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -15,17 +13,13 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from oslo.config import cfg
+from oslo_config import cfg
 
-from ceilometer.central import plugin
+from ceilometer.agent import plugin_base
 from ceilometer import neutron_client
-from ceilometer import plugin as base_plugin
 
 
-cfg.CONF.import_group('service_types', 'ceilometer.neutron_client')
-
-
-class _BaseServicesDiscovery(base_plugin.DiscoveryBase):
+class _BaseServicesDiscovery(plugin_base.DiscoveryBase):
 
     def __init__(self):
         super(_BaseServicesDiscovery, self).__init__()
@@ -33,7 +27,7 @@ class _BaseServicesDiscovery(base_plugin.DiscoveryBase):
 
 
 class LBPoolsDiscovery(_BaseServicesDiscovery):
-    @plugin.check_keystone(cfg.CONF.service_types.neutron)
+    @plugin_base.check_keystone(cfg.CONF.service_types.neutron)
     def discover(self, manager, param=None):
         """Discover resources to monitor."""
 
@@ -43,7 +37,7 @@ class LBPoolsDiscovery(_BaseServicesDiscovery):
 
 
 class LBVipsDiscovery(_BaseServicesDiscovery):
-    @plugin.check_keystone(cfg.CONF.service_types.neutron)
+    @plugin_base.check_keystone(cfg.CONF.service_types.neutron)
     def discover(self, manager, param=None):
         """Discover resources to monitor."""
 
@@ -53,7 +47,7 @@ class LBVipsDiscovery(_BaseServicesDiscovery):
 
 
 class LBMembersDiscovery(_BaseServicesDiscovery):
-    @plugin.check_keystone(cfg.CONF.service_types.neutron)
+    @plugin_base.check_keystone(cfg.CONF.service_types.neutron)
     def discover(self, manager, param=None):
         """Discover resources to monitor."""
 
@@ -63,7 +57,7 @@ class LBMembersDiscovery(_BaseServicesDiscovery):
 
 
 class LBHealthMonitorsDiscovery(_BaseServicesDiscovery):
-    @plugin.check_keystone(cfg.CONF.service_types.neutron)
+    @plugin_base.check_keystone(cfg.CONF.service_types.neutron)
     def discover(self, manager, param=None):
         """Discover resources to monitor."""
 
@@ -72,7 +66,7 @@ class LBHealthMonitorsDiscovery(_BaseServicesDiscovery):
 
 
 class VPNServicesDiscovery(_BaseServicesDiscovery):
-    @plugin.check_keystone(cfg.CONF.service_types.neutron)
+    @plugin_base.check_keystone(cfg.CONF.service_types.neutron)
     def discover(self, manager, param=None):
         """Discover resources to monitor."""
 
@@ -82,7 +76,7 @@ class VPNServicesDiscovery(_BaseServicesDiscovery):
 
 
 class IPSecConnectionsDiscovery(_BaseServicesDiscovery):
-    @plugin.check_keystone(cfg.CONF.service_types.neutron)
+    @plugin_base.check_keystone(cfg.CONF.service_types.neutron)
     def discover(self, manager, param=None):
         """Discover resources to monitor."""
 
@@ -91,7 +85,7 @@ class IPSecConnectionsDiscovery(_BaseServicesDiscovery):
 
 
 class FirewallDiscovery(_BaseServicesDiscovery):
-    @plugin.check_keystone(cfg.CONF.service_types.neutron)
+    @plugin_base.check_keystone(cfg.CONF.service_types.neutron)
     def discover(self, manager, param=None):
         """Discover resources to monitor."""
 
@@ -101,7 +95,7 @@ class FirewallDiscovery(_BaseServicesDiscovery):
 
 
 class FirewallPolicyDiscovery(_BaseServicesDiscovery):
-    @plugin.check_keystone(cfg.CONF.service_types.neutron)
+    @plugin_base.check_keystone(cfg.CONF.service_types.neutron)
     def discover(self, manager, param=None):
         """Discover resources to monitor."""
 
