@@ -15,12 +15,12 @@
 
 import abc
 
-from oslo.config import cfg
+from oslo_config import cfg
 import requests
 from requests import auth
 import six
 
-from ceilometer.openstack.common.gettextutils import _
+from ceilometer.i18n import _
 from ceilometer.openstack.common import log
 
 
@@ -32,7 +32,7 @@ LOG = log.getLogger(__name__)
 
 
 @six.add_metaclass(abc.ABCMeta)
-class _Base():
+class _Base(object):
     """Base class of OpenDaylight REST APIs Clients."""
 
     @abc.abstractproperty
@@ -154,7 +154,7 @@ class HostTrackerAPIClient(_Base):
         return self.request('/hosts/inactive', container_name)
 
 
-class Client():
+class Client(object):
 
     def __init__(self, endpoint, params):
         self.statistics = StatisticsAPIClient(self)
