@@ -1,9 +1,6 @@
 #
 # Copyright 2013 eNovance
 #
-# Author: Julien Danjou <julien@danjou.info>,
-#         Tyaptin Ilya <ityaptin@mirantis.com>
-#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -21,10 +18,11 @@
 import socket
 
 import msgpack
-from oslo.config import cfg
-from oslo.utils import netutils
+from oslo_config import cfg
+from oslo_utils import netutils
 
-from ceilometer.openstack.common.gettextutils import _
+import ceilometer
+from ceilometer.i18n import _
 from ceilometer.openstack.common import log
 from ceilometer import publisher
 from ceilometer.publisher import utils
@@ -40,7 +38,11 @@ class UDPPublisher(publisher.PublisherBase):
         self.host, self.port = netutils.parse_host_port(
             parsed_url.netloc,
             default_port=cfg.CONF.collector.udp_port)
-        self.socket = socket.socket(socket.AF_INET,
+        if netutils.is_valid_ipv6(self.host):
+            addr_family = socket.AF_INET6
+        else:
+            addr_family = socket.AF_INET
+        self.socket = socket.socket(addr_family,
                                     socket.SOCK_DGRAM)
 
     def publish_samples(self, context, samples):
@@ -52,8 +54,7 @@ class UDPPublisher(publisher.PublisherBase):
 
         for sample in samples:
             msg = utils.meter_message_from_counter(
-                sample,
-                cfg.CONF.publisher.metering_secret)
+                sample, cfg.CONF.publisher.telemetry_secret)
             host = self.host
             port = self.port
             LOG.debug(_("Publishing sample %(msg)s over UDP to "
@@ -65,3 +66,11 @@ class UDPPublisher(publisher.PublisherBase):
             except Exception as e:
                 LOG.warn(_("Unable to send sample over UDP"))
                 LOG.exception(e)
+
+    def publish_events(self, context, events):
+        """Send an event message for publishing
+
+        :param context: Execution context from the service or RPC call
+        :param events: events from pipeline after transformation
+        """
+        raise ceilometer.NotImplementedError
