@@ -18,16 +18,16 @@
 """Common functions for MongoDB and DB2 backends
 """
 
-
 import time
-
-from oslo.config import cfg
-from oslo.utils import netutils
-import pymongo
-import six
 import weakref
 
-from ceilometer.openstack.common.gettextutils import _
+from oslo_config import cfg
+from oslo_utils import netutils
+import pymongo
+import six
+from six.moves.urllib import parse
+
+from ceilometer.i18n import _
 from ceilometer.openstack.common import log
 
 LOG = log.getLogger(__name__)
@@ -73,18 +73,18 @@ def make_events_query_from_filter(event_filter):
 
     :param event_filter: storage.EventFilter object.
     """
-    q = {}
-    ts_range = make_timestamp_range(event_filter.start_time,
-                                    event_filter.end_time)
+    query = {}
+    q_list = []
+    ts_range = make_timestamp_range(event_filter.start_timestamp,
+                                    event_filter.end_timestamp)
     if ts_range:
-        q['timestamp'] = ts_range
+        q_list.append({'timestamp': ts_range})
     if event_filter.event_type:
-        q['event_type'] = event_filter.event_type
+        q_list.append({'event_type': event_filter.event_type})
     if event_filter.message_id:
-        q['_id'] = event_filter.message_id
+        q_list.append({'_id': event_filter.message_id})
 
     if event_filter.traits_filter:
-        q.setdefault('traits')
         for trait_filter in event_filter.traits_filter:
             op = trait_filter.pop('op', 'eq')
             dict_query = {}
@@ -101,14 +101,10 @@ def make_events_query_from_filter(event_filter):
                                               v if op == 'eq'
                                               else {OP_SIGN[op]: v})
             dict_query = {'$elemMatch': dict_query}
-            if q['traits'] is None:
-                q['traits'] = dict_query
-            elif q.get('$and') is None:
-                q.setdefault('$and', [{'traits': q.pop('traits')},
-                                      {'traits': dict_query}])
-            else:
-                q['$and'].append({'traits': dict_query})
-    return q
+            q_list.append({'traits': dict_query})
+    if q_list:
+        query = {'$and': q_list}
+    return query
 
 
 def make_query_from_filter(sample_filter, require_meter=True):
@@ -130,8 +126,8 @@ def make_query_from_filter(sample_filter, require_meter=True):
     elif require_meter:
         raise RuntimeError('Missing required meter specifier')
 
-    ts_range = make_timestamp_range(sample_filter.start,
-                                    sample_filter.end,
+    ts_range = make_timestamp_range(sample_filter.start_timestamp,
+                                    sample_filter.end_timestamp,
                                     sample_filter.start_timestamp_op,
                                     sample_filter.end_timestamp_op)
 
@@ -147,11 +143,82 @@ def make_query_from_filter(sample_filter, require_meter=True):
 
     # so the samples call metadata resource_metadata, so we convert
     # to that.
-    q.update(dict(('resource_%s' % k, v)
-                  for (k, v) in six.iteritems(sample_filter.metaquery)))
+    q.update(dict(
+        ('resource_%s' % k, v) for (k, v) in six.iteritems(
+            improve_keys(sample_filter.metaquery, metaquery=True))))
     return q
 
 
+def quote_key(key, reverse=False):
+    """Prepare key for storage data in MongoDB.
+
+    :param key: key that should be quoted
+    :param reverse: boolean, True --- if we need a reverse order of the keys
+                    parts
+    :return: iter of quoted part of the key
+    """
+    r = -1 if reverse else 1
+
+    for k in key.split('.')[::r]:
+        if k.startswith('$'):
+            k = parse.quote(k)
+        yield k
+
+
+def improve_keys(data, metaquery=False):
+    """Improves keys in dict if they contained '.' or started with '$'.
+
+    :param data: is a dictionary where keys need to be checked and improved
+    :param metaquery: boolean, if True dots are not escaped from the keys
+    :return: improved dictionary if keys contained dots or started with '$':
+            {'a.b': 'v'} -> {'a': {'b': 'v'}}
+            {'$ab': 'v'} -> {'%24ab': 'v'}
+    """
+    if not isinstance(data, dict):
+        return data
+
+    if metaquery:
+        for key in data.iterkeys():
+            if '.$' in key:
+                key_list = []
+                for k in quote_key(key):
+                    key_list.append(k)
+                new_key = '.'.join(key_list)
+                data[new_key] = data.pop(key)
+    else:
+        for key, value in data.items():
+            if isinstance(value, dict):
+                improve_keys(value)
+            if '.' in key:
+                new_dict = {}
+                for k in quote_key(key, reverse=True):
+                    new = {}
+                    new[k] = new_dict if new_dict else data.pop(key)
+                    new_dict = new
+                data.update(new_dict)
+            else:
+                if key.startswith('$'):
+                    new_key = parse.quote(key)
+                    data[new_key] = data.pop(key)
+    return data
+
+
+def unquote_keys(data):
+    """Restores initial view of 'quoted' keys in dictionary data
+
+    :param data: is a dictionary
+    :return: data with restored keys if they were 'quoted'.
+    """
+    if isinstance(data, dict):
+        for key, value in data.items():
+            if isinstance(value, dict):
+                unquote_keys(value)
+            if key.startswith('%24'):
+                k = parse.unquote(key)
+                data[k] = data.pop(key)
+    return data
+
+
 class ConnectionPool(object):
 
     def __init__(self):
@@ -186,8 +253,7 @@ class ConnectionPool(object):
                         url,
                         replicaSet=cfg.CONF.database.mongodb_replica_set))
             else:
-                client = MongoProxy(
-                    pymongo.MongoClient(url, safe=True))
+                client = MongoProxy(pymongo.MongoClient(url))
             return client
         except pymongo.errors.ConnectionFailure as e:
             LOG.warn(_('Unable to connect to the database server: '
@@ -204,7 +270,8 @@ class QueryTransformer(object):
                  ">=": "$gte",
                  "=>": "$gte",
                  "!=": "$ne",
-                 "in": "$in"}
+                 "in": "$in",
+                 "=~": "$regex"}
 
     complex_operators = {"or": "$or",
                          "and": "$and"}
@@ -380,7 +447,7 @@ class MongoProxy(object):
         insert, wrap this method in the MongoConn.
         Else wrap getting attribute with MongoProxy.
         """
-        if item == 'name':
+        if item in ('name', 'database'):
             return getattr(self.conn, item)
         if item in MONGO_METHODS:
             return MongoConn(getattr(self.conn, item))
