@@ -1,6 +1,3 @@
-# Author: John Tran <jhtran@att.com>
-#         Julien Danjou <julien@danjou.info>
-#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -46,7 +43,12 @@ class QueryTransformer(object):
                  ">=": operator.ge,
                  "=>": operator.ge,
                  "!=": operator.ne,
-                 "in": lambda field_name, values: field_name.in_(values)}
+                 "in": lambda field_name, values: field_name.in_(values),
+                 "=~": lambda field, value: field.op("regexp")(value)}
+
+    # operators which are differs for different dialects
+    dialect_operators = {'postgresql': {'=~': (lambda field, value:
+                                               field.op("~")(value))}}
 
     complex_operators = {"or": or_,
                          "and": and_,
@@ -55,9 +57,14 @@ class QueryTransformer(object):
     ordering_functions = {"asc": asc,
                           "desc": desc}
 
-    def __init__(self, table, query):
+    def __init__(self, table, query, dialect='mysql'):
         self.table = table
         self.query = query
+        self.dialect_name = dialect
+
+    def _get_operator(self, op):
+        return (self.dialect_operators.get(self.dialect_name, {}).get(op)
+                or self.operators[op])
 
     def _handle_complex_op(self, complex_op, nodes):
         op = self.complex_operators[complex_op]
@@ -70,7 +77,7 @@ class QueryTransformer(object):
         return op(*element_list)
 
     def _handle_simple_op(self, simple_op, nodes):
-        op = self.operators[simple_op]
+        op = self._get_operator(simple_op)
         field_name = nodes.keys()[0]
         value = nodes.values()[0]
         if field_name.startswith('resource_metadata.'):
@@ -82,7 +89,6 @@ class QueryTransformer(object):
         if op == self.operators["in"]:
             raise ceilometer.NotImplementedError('Metadata query with in '
                                                  'operator is not implemented')
-
         field_name = field_name[len('resource_metadata.'):]
         meta_table = META_TYPE_MAP[type(value)]
         meta_alias = aliased(meta_table)
@@ -123,18 +129,3 @@ class QueryTransformer(object):
 
     def get_query(self):
         return self.query
-
-
-trait_models_dict = {'string': models.Trait.t_string,
-                     'integer': models.Trait.t_int,
-                     'datetime': models.Trait.t_datetime,
-                     'float': models.Trait.t_float}
-
-
-def trait_op_condition(conditions, trait_type, value, op='eq'):
-    trait_model = trait_models_dict[trait_type]
-    op_dict = {'eq': (trait_model == value), 'lt': (trait_model < value),
-               'le': (trait_model <= value), 'gt': (trait_model > value),
-               'ge': (trait_model >= value), 'ne': (trait_model != value)}
-    conditions.append(op_dict[op])
-    return conditions
