@@ -1,8 +1,6 @@
 #
 # Copyright 2013 IBM Corp
 #
-# Author: Tong Li <litong01@us.ibm.com>
-#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -19,7 +17,7 @@
 import datetime
 
 import mock
-from oslo.utils import timeutils
+from oslo_utils import timeutils
 from oslotest import base
 
 from ceilometer.alarm import evaluator
@@ -73,6 +71,20 @@ class TestEvaluatorBaseClass(base.BaseTestCase):
         mock_utcnow.return_value = datetime.datetime(2014, 1, 2, 5, 0, 0)
         self.assertFalse(cls.within_time_constraint(alarm))
 
+    @mock.patch.object(timeutils, 'utcnow')
+    def test_base_time_constraints_by_month(self, mock_utcnow):
+        alarm = mock.MagicMock()
+        alarm.time_constraints = [
+            {'name': 'test',
+             'description': 'test',
+             'start': '0 11 31 1,3,5,7,8,10,12 *',  # every 31st at 11:00
+             'duration': 10800,  # 3 hours
+             'timezone': ''},
+        ]
+        cls = evaluator.Evaluator
+        mock_utcnow.return_value = datetime.datetime(2015, 3, 31, 11, 30, 0)
+        self.assertTrue(cls.within_time_constraint(alarm))
+
     @mock.patch.object(timeutils, 'utcnow')
     def test_base_time_constraints_complex(self, mock_utcnow):
         alarm = mock.MagicMock()
