@@ -14,20 +14,23 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-"""Tests for ceilometer/alarm/threshold_evaluation.py
+
+"""Tests for ceilometer/alarm/evaluator/combination.py
 """
+
 import datetime
-import mock
-import pytz
 import uuid
 
-from oslo.utils import timeutils
+from ceilometerclient import exc
+from ceilometerclient.v2 import alarms
+import mock
+from oslo_utils import timeutils
+import pytz
 
 from ceilometer.alarm.evaluator import combination
 from ceilometer.alarm.storage import models
 from ceilometer.tests.alarm.evaluator import base
-from ceilometerclient import exc
-from ceilometerclient.v2 import alarms
+from ceilometer.tests import constants
 
 
 class TestEvaluate(base.TestEvaluatorBase):
@@ -43,8 +46,8 @@ class TestEvaluate(base.TestEvaluatorBase):
                          project_id='snafu',
                          alarm_id=str(uuid.uuid4()),
                          state='insufficient data',
-                         state_timestamp=None,
-                         timestamp=None,
+                         state_timestamp=constants.MIN_DATETIME,
+                         timestamp=constants.MIN_DATETIME,
                          insufficient_data_actions=[],
                          ok_actions=[],
                          alarm_actions=[],
@@ -55,7 +58,8 @@ class TestEvaluate(base.TestEvaluatorBase):
                                  '9cfc3e51-2ff1-4b1d-ac01-c1bd4c6d0d1e',
                                  '1d441595-d069-4e05-95ab-8693ba6a8302'],
                              operator='or',
-                         )),
+                         ),
+                         severity='critical'),
             models.Alarm(name='and-alarm',
                          description='the and alarm',
                          type='combination',
@@ -64,8 +68,8 @@ class TestEvaluate(base.TestEvaluatorBase):
                          project_id='snafu',
                          alarm_id=str(uuid.uuid4()),
                          state='insufficient data',
-                         state_timestamp=None,
-                         timestamp=None,
+                         state_timestamp=constants.MIN_DATETIME,
+                         timestamp=constants.MIN_DATETIME,
                          insufficient_data_actions=[],
                          ok_actions=[],
                          alarm_actions=[],
@@ -76,7 +80,8 @@ class TestEvaluate(base.TestEvaluatorBase):
                                  'b82734f4-9d06-48f3-8a86-fa59a0c99dc8',
                                  '15a700e5-2fe8-4b3d-8c55-9e92831f6a2b'],
                              operator='and',
-                         ))
+                         ),
+                         severity='critical')
         ]
 
     @staticmethod
