@@ -1,8 +1,6 @@
 #
 # Copyright 2013 Red Hat, Inc
 #
-# Author: Eoghan Glynn <eglynn@redhat.com>
-#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -17,8 +15,9 @@
 """Tests for ceilometer.alarm.service.PartitionedAlarmService.
 """
 import contextlib
+
 import mock
-from oslo.config import fixture as fixture_config
+from oslo_config import fixture as fixture_config
 from stevedore import extension
 
 from ceilometer.alarm import service
