@@ -1,8 +1,6 @@
 #
 # Copyright 2012 New Dream Network, LLC (DreamHost)
 #
-# Author: Doug Hellmann <doug.hellmann@dreamhost.com>
-#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -17,8 +15,9 @@
 """Base classes for API tests.
 """
 
-from oslo.config import cfg
-from oslo.config import fixture as fixture_config
+from oslo_config import cfg
+from oslo_config import fixture as fixture_config
+from oslo_policy import opts
 import pecan
 import pecan.testing
 
@@ -26,7 +25,6 @@ from ceilometer.tests import db as db_test_base
 
 OPT_GROUP_NAME = 'keystone_authtoken'
 cfg.CONF.import_group(OPT_GROUP_NAME, "keystonemiddleware.auth_token")
-cfg.CONF.import_opt("policy_file", "ceilometer.openstack.common.policy")
 
 
 class FunctionalTest(db_test_base.TestBase):
@@ -42,23 +40,20 @@ class FunctionalTest(db_test_base.TestBase):
         super(FunctionalTest, self).setUp()
         self.CONF = self.useFixture(fixture_config.Config()).conf
         self.setup_messaging(self.CONF)
+        opts.set_defaults(self.CONF)
 
         self.CONF.set_override("auth_version", "v2.0",
                                group=OPT_GROUP_NAME)
         self.CONF.set_override("policy_file",
-                               self.path_get('etc/ceilometer/policy.json'))
+                               self.path_get('etc/ceilometer/policy.json'),
+                               group='oslo_policy')
         self.app = self._make_app()
 
     def _make_app(self, enable_acl=False):
-        # Determine where we are so we can set up paths in the config
-        root_dir = self.path_get()
-
         self.config = {
             'app': {
                 'root': 'ceilometer.api.controllers.root.RootController',
                 'modules': ['ceilometer.api'],
-                'static_root': '%s/public' % root_dir,
-                'template_path': '%s/ceilometer/api/templates' % root_dir,
                 'enable_acl': enable_acl,
             },
             'wsme': {
