@@ -1,8 +1,6 @@
 #
 # Copyright 2013 Rackspace Hosting.
 #
-# Author: Monsyne Dragon <mdragon@rackspace.com>
-#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -19,16 +17,17 @@ import datetime
 
 import jsonpath_rw
 import mock
-from oslo.config import cfg as oslo_cfg
+from oslo_config import fixture as fixture_config
 import six
 
 from ceilometer.event import converter
-from ceilometer.storage import models
+from ceilometer.event.storage import models
 from ceilometer.tests import base
 
 
 class ConverterBase(base.BaseTestCase):
-    def _create_test_notification(self, event_type, message_id, **kw):
+    @staticmethod
+    def _create_test_notification(event_type, message_id, **kw):
         return dict(event_type=event_type,
                     message_id=message_id,
                     priority="INFO",
@@ -546,7 +545,7 @@ class TestEventDefinition(ConverterBase):
         edef = converter.EventDefinition(cfg, self.fake_plugin_mgr)
         self.assertTrue(edef.is_catchall)
 
-    @mock.patch('oslo.utils.timeutils.utcnow')
+    @mock.patch('oslo_utils.timeutils.utcnow')
     def test_extract_when(self, mock_utcnow):
         now = datetime.datetime.utcnow()
         modified = now + datetime.timedelta(minutes=1)
@@ -595,7 +594,7 @@ class TestNotificationConverter(ConverterBase):
 
     def setUp(self):
         super(TestNotificationConverter, self).setUp()
-
+        self.CONF = self.useFixture(fixture_config.Config()).conf
         self.valid_event_def1 = [{
             'event_type': 'compute.instance.create.*',
             'traits': {
@@ -623,7 +622,7 @@ class TestNotificationConverter(ConverterBase):
             host='cydonia')
         self.fake_plugin_mgr = {}
 
-    @mock.patch('oslo.utils.timeutils.utcnow')
+    @mock.patch('oslo_utils.timeutils.utcnow')
     def test_converter_missing_keys(self, mock_utcnow):
         # test a malformed notification
         now = datetime.datetime.utcnow()
@@ -705,19 +704,73 @@ class TestNotificationConverter(ConverterBase):
         e = c.to_event(self.test_notification2)
         self.assertIsNotValidEvent(e, self.test_notification2)
 
+    @staticmethod
+    def _convert_message(convert, level):
+        message = {'priority': level, 'event_type': "foo",
+                   'message_id': "abc", 'publisher_id': "1"}
+        return convert.to_event(message)
+
+    def test_store_raw_all(self):
+        self.CONF.event.store_raw = ['info', 'error']
+        c = converter.NotificationEventsConverter(
+            [], self.fake_plugin_mgr)
+        self.assertTrue(self._convert_message(c, 'info').raw)
+        self.assertTrue(self._convert_message(c, 'error').raw)
+
+    def test_store_raw_info_only(self):
+        self.CONF.event.store_raw = ['info']
+        c = converter.NotificationEventsConverter(
+            [], self.fake_plugin_mgr)
+        self.assertTrue(self._convert_message(c, 'info').raw)
+        self.assertFalse(self._convert_message(c, 'error').raw)
+
+    def test_store_raw_error_only(self):
+        self.CONF.event.store_raw = ['error']
+        c = converter.NotificationEventsConverter(
+            [], self.fake_plugin_mgr)
+        self.assertFalse(self._convert_message(c, 'info').raw)
+        self.assertTrue(self._convert_message(c, 'error').raw)
+
+    def test_store_raw_skip_all(self):
+        c = converter.NotificationEventsConverter(
+            [], self.fake_plugin_mgr)
+        self.assertFalse(self._convert_message(c, 'info').raw)
+        self.assertFalse(self._convert_message(c, 'error').raw)
+
+    def test_store_raw_info_only_no_case(self):
+        self.CONF.event.store_raw = ['INFO']
+        c = converter.NotificationEventsConverter(
+            [], self.fake_plugin_mgr)
+        self.assertTrue(self._convert_message(c, 'info').raw)
+        self.assertFalse(self._convert_message(c, 'error').raw)
+
+    def test_store_raw_bad_skip_all(self):
+        self.CONF.event.store_raw = ['unknown']
+        c = converter.NotificationEventsConverter(
+            [], self.fake_plugin_mgr)
+        self.assertFalse(self._convert_message(c, 'info').raw)
+        self.assertFalse(self._convert_message(c, 'error').raw)
+
+    def test_store_raw_bad_and_good(self):
+        self.CONF.event.store_raw = ['info', 'unknown']
+        c = converter.NotificationEventsConverter(
+            [], self.fake_plugin_mgr)
+        self.assertTrue(self._convert_message(c, 'info').raw)
+        self.assertFalse(self._convert_message(c, 'error').raw)
+
     @mock.patch('ceilometer.event.converter.get_config_file',
                 mock.Mock(return_value=None))
     def test_setup_events_default_config(self):
-        oslo_cfg.CONF.set_override('drop_unmatched_notifications',
-                                   False, group='event')
+        self.CONF.set_override('drop_unmatched_notifications',
+                               False, group='event')
 
         c = converter.setup_events(self.fake_plugin_mgr)
         self.assertIsInstance(c, converter.NotificationEventsConverter)
         self.assertEqual(1, len(c.definitions))
         self.assertTrue(c.definitions[0].is_catchall)
 
-        oslo_cfg.CONF.set_override('drop_unmatched_notifications',
-                                   True, group='event')
+        self.CONF.set_override('drop_unmatched_notifications',
+                               True, group='event')
 
         c = converter.setup_events(self.fake_plugin_mgr)
         self.assertIsInstance(c, converter.NotificationEventsConverter)
