@@ -15,7 +15,7 @@
 
 import datetime
 
-from oslo.utils import timeutils
+from oslo_utils import timeutils
 from oslotest import base
 
 from ceilometer.network import statistics
@@ -25,7 +25,8 @@ from ceilometer import sample
 
 class TestBase(base.BaseTestCase):
 
-    def test_subclass_ok(self):
+    @staticmethod
+    def test_subclass_ok():
 
         class OkSubclass(statistics._Base):
 
@@ -76,7 +77,8 @@ class TestBaseGetSamples(base.BaseTestCase):
         statistics._Base.drivers = {}
         super(TestBaseGetSamples, self).tearDown()
 
-    def _setup_ext_mgr(self, **drivers):
+    @staticmethod
+    def _setup_ext_mgr(**drivers):
         statistics._Base.drivers = drivers
 
     def _make_fake_driver(self, *return_values):
@@ -93,7 +95,8 @@ class TestBaseGetSamples(base.BaseTestCase):
                 yield retval
         return FakeDriver
 
-    def _make_timestamps(self, count):
+    @staticmethod
+    def _make_timestamps(count):
         now = timeutils.utcnow()
         return [timeutils.isotime(now + datetime.timedelta(seconds=i))
                 for i in range(count)]
@@ -104,15 +107,15 @@ class TestBaseGetSamples(base.BaseTestCase):
 
     def _assert_sample(self, s, volume, resource_id, resource_metadata,
                        timestamp):
-            self.assertEqual(s.name, 'foo')
-            self.assertEqual(s.type, sample.TYPE_CUMULATIVE)
-            self.assertEqual(s.unit, 'bar')
-            self.assertEqual(s.volume, volume)
+            self.assertEqual('foo', s.name)
+            self.assertEqual(sample.TYPE_CUMULATIVE, s.type)
+            self.assertEqual('bar', s.unit)
+            self.assertEqual(volume, s.volume)
             self.assertIsNone(s.user_id)
             self.assertIsNone(s.project_id)
-            self.assertEqual(s.resource_id, resource_id)
-            self.assertEqual(s.timestamp, timestamp)
-            self.assertEqual(s.resource_metadata, resource_metadata)
+            self.assertEqual(resource_id, s.resource_id)
+            self.assertEqual(timestamp, s.timestamp)
+            self.assertEqual(resource_metadata, s.resource_metadata)
 
     def test_get_samples_one_driver_one_resource(self):
         times = self._make_timestamps(2)
@@ -124,7 +127,7 @@ class TestBaseGetSamples(base.BaseTestCase):
 
         samples = self._get_samples('http://foo')
 
-        self.assertEqual(len(samples), 1)
+        self.assertEqual(1, len(samples))
         self._assert_sample(samples[0], 1, 'a', {'spam': 'egg'}, times[0])
 
     def test_get_samples_one_driver_two_resource(self):
@@ -138,7 +141,7 @@ class TestBaseGetSamples(base.BaseTestCase):
 
         samples = self._get_samples('http://foo', 'http://bar')
 
-        self.assertEqual(len(samples), 2)
+        self.assertEqual(2, len(samples))
         self._assert_sample(samples[0], 1, 'a', {'spam': 'egg'}, times[0])
         self._assert_sample(samples[1], 2, 'b', None, times[1])
 
@@ -155,7 +158,7 @@ class TestBaseGetSamples(base.BaseTestCase):
 
         samples = self._get_samples('http://foo')
 
-        self.assertEqual(len(samples), 1)
+        self.assertEqual(1, len(samples))
         self._assert_sample(samples[0], 1, 'a', {'spam': 'egg'}, times[0])
 
     def test_get_samples_multi_samples(self):
@@ -168,7 +171,7 @@ class TestBaseGetSamples(base.BaseTestCase):
 
         samples = self._get_samples('http://foo')
 
-        self.assertEqual(len(samples), 2)
+        self.assertEqual(2, len(samples))
         self._assert_sample(samples[0], 1, 'a', {'spam': 'egg'}, times[0])
         self._assert_sample(samples[1], 2, 'b', None, times[1])
 
@@ -179,7 +182,7 @@ class TestBaseGetSamples(base.BaseTestCase):
 
         samples = self._get_samples('http://foo')
 
-        self.assertEqual(len(samples), 0)
+        self.assertEqual(0, len(samples))
 
     def test_get_samples_return_no_generator(self):
         class NoneFakeDriver(driver.Driver):
