@@ -1,8 +1,6 @@
 #
 # Copyright 2012 New Dream Network, LLC (DreamHost)
 #
-# Author: Doug Hellmann <doug.hellmann@dreamhost.com>
-#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -24,6 +22,7 @@
 """
 
 from ceilometer.alarm.storage import impl_mongodb as impl_mongodb_alarm
+from ceilometer.event.storage import impl_mongodb as impl_mongodb_event
 from ceilometer.storage import base
 from ceilometer.storage import impl_mongodb
 from ceilometer.tests import base as test_base
@@ -32,7 +31,8 @@ from ceilometer.tests.storage import test_storage_scenarios
 
 
 @tests_db.run_with('mongodb')
-class MongoDBConnection(tests_db.TestBase):
+class MongoDBConnection(tests_db.TestBase,
+                        tests_db.MixinTestsWithBackendScenarios):
     def test_connection_pooling(self):
         test_conn = impl_mongodb.Connection(self.db_manager.url)
         self.assertEqual(self.conn.conn, test_conn.conn)
@@ -54,7 +54,8 @@ class MongoDBConnection(tests_db.TestBase):
 
 
 @tests_db.run_with('mongodb')
-class MongoDBTestMarkerBase(test_storage_scenarios.DBTestBase):
+class MongoDBTestMarkerBase(test_storage_scenarios.DBTestBase,
+                            tests_db.MixinTestsWithBackendScenarios):
     # NOTE(Fengqian): All these three test case are the same for resource
     # and meter collection. As to alarm, we will set up in AlarmTestPagination.
     def test_get_marker(self):
@@ -83,36 +84,56 @@ class MongoDBTestMarkerBase(test_storage_scenarios.DBTestBase):
 
 
 @tests_db.run_with('mongodb')
-class IndexTest(tests_db.TestBase):
-    def test_meter_ttl_index_absent(self):
+class IndexTest(tests_db.TestBase,
+                tests_db.MixinTestsWithBackendScenarios):
+
+    def _test_ttl_index_absent(self, conn, coll_name, ttl_opt):
         # create a fake index and check it is deleted
-        self.conn.db.meter.ensure_index('foo', name='meter_ttl')
-        self.CONF.set_override('time_to_live', -1, group='database')
-        self.conn.upgrade()
-        self.assertTrue(self.conn.db.meter.ensure_index('foo',
-                                                        name='meter_ttl'))
-        self.CONF.set_override('time_to_live', 456789, group='database')
-        self.conn.upgrade()
-        self.assertFalse(self.conn.db.meter.ensure_index('foo',
-                                                         name='meter_ttl'))
+        coll = getattr(conn.db, coll_name)
+        index_name = '%s_ttl' % coll_name
+        self.CONF.set_override(ttl_opt, -1, group='database')
+        conn.upgrade()
+        self.assertNotIn(index_name, coll.index_information())
+
+        self.CONF.set_override(ttl_opt, 456789, group='database')
+        conn.upgrade()
+        self.assertEqual(456789,
+                         coll.index_information()
+                         [index_name]['expireAfterSeconds'])
+
+    def test_meter_ttl_index_absent(self):
+        self._test_ttl_index_absent(self.conn, 'meter',
+                                    'metering_time_to_live')
+
+    def test_event_ttl_index_absent(self):
+        self._test_ttl_index_absent(self.event_conn, 'event',
+                                    'event_time_to_live')
+
+    def _test_ttl_index_present(self, conn, coll_name, ttl_opt):
+        coll = getattr(conn.db, coll_name)
+        self.CONF.set_override(ttl_opt, 456789, group='database')
+        conn.upgrade()
+        index_name = '%s_ttl' % coll_name
+        self.assertEqual(456789,
+                         coll.index_information()
+                         [index_name]['expireAfterSeconds'])
+
+        self.CONF.set_override(ttl_opt, -1, group='database')
+        conn.upgrade()
+        self.assertNotIn(index_name, coll.index_information())
 
     def test_meter_ttl_index_present(self):
-        self.CONF.set_override('time_to_live', 456789, group='database')
-        self.conn.upgrade()
-        self.assertFalse(self.conn.db.meter.ensure_index('foo',
-                                                         name='meter_ttl'))
-        self.assertEqual(456789,
-                         self.conn.db.meter.index_information()
-                         ['meter_ttl']['expireAfterSeconds'])
+        self._test_ttl_index_present(self.conn, 'meter',
+                                     'metering_time_to_live')
 
-        self.CONF.set_override('time_to_live', -1, group='database')
-        self.conn.upgrade()
-        self.assertTrue(self.conn.db.meter.ensure_index('foo',
-                                                        name='meter_ttl'))
+    def test_event_ttl_index_present(self):
+        self._test_ttl_index_present(self.event_conn, 'event',
+                                     'event_time_to_live')
 
 
 @tests_db.run_with('mongodb')
-class AlarmTestPagination(test_storage_scenarios.AlarmTestBase):
+class AlarmTestPagination(test_storage_scenarios.AlarmTestBase,
+                          tests_db.MixinTestsWithBackendScenarios):
     def test_alarm_get_marker(self):
         self.add_some_alarms()
         marker_pairs = {'name': 'red-alert'}
@@ -156,7 +177,6 @@ class CapabilitiesTest(test_base.BaseTestCase):
                                     'metadata': True,
                                     'complex': False}},
             'samples': {'pagination': False,
-                        'groupby': False,
                         'query': {'simple': True,
                                   'metadata': True,
                                   'complex': True}},
@@ -175,12 +195,18 @@ class CapabilitiesTest(test_base.BaseTestCase):
                                                'stddev': True,
                                                'cardinality': True}}
                            },
-            'events': {'query': {'simple': True}}
         }
 
         actual_capabilities = impl_mongodb.Connection.get_capabilities()
         self.assertEqual(expected_capabilities, actual_capabilities)
 
+    def test_event_capabilities(self):
+        expected_capabilities = {
+            'events': {'query': {'simple': True}},
+        }
+        actual_capabilities = impl_mongodb_event.Connection.get_capabilities()
+        self.assertEqual(expected_capabilities, actual_capabilities)
+
     def test_alarm_capabilities(self):
         expected_capabilities = {
             'alarms': {'query': {'simple': True,
