@@ -1,8 +1,6 @@
 #
 # Copyright 2014 Red Hat, Inc
 #
-# Author: Eoghan Glynn <eglynn@redhat.com>
-#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -74,6 +72,15 @@ class TestDecoupledPipeline(pipeline_base.BasePipelineTestCase):
             'publishers': ['except'],
         })
 
+    def _dup_pipeline_name_cfg(self):
+        self.pipeline_cfg['sources'].append({
+            'name': 'test_source',
+            'interval': 5,
+            'counters': ['b'],
+            'resources': [],
+            'sinks': ['test_sink']
+        })
+
     def _set_pipeline_cfg(self, field, value):
         if field in self.pipeline_cfg['sources'][0]:
             self.pipeline_cfg['sources'][0][field] = value
@@ -146,19 +153,19 @@ class TestDecoupledPipeline(pipeline_base.BasePipelineTestCase):
         with pipeline_manager.publisher(None) as p:
             p([self.test_counter])
 
-        self.assertEqual(len(pipeline_manager.pipelines), 2)
-        self.assertEqual(str(pipeline_manager.pipelines[0]),
-                         'test_source:test_sink')
-        self.assertEqual(str(pipeline_manager.pipelines[1]),
-                         'test_source:second_sink')
+        self.assertEqual(2, len(pipeline_manager.pipelines))
+        self.assertEqual('test_source:test_sink',
+                         str(pipeline_manager.pipelines[0]))
+        self.assertEqual('test_source:second_sink',
+                         str(pipeline_manager.pipelines[1]))
         test_publisher = pipeline_manager.pipelines[0].publishers[0]
         new_publisher = pipeline_manager.pipelines[1].publishers[0]
         for publisher, sfx in [(test_publisher, '_update'),
                                (new_publisher, '_new')]:
-            self.assertEqual(len(publisher.samples), 2)
-            self.assertEqual(publisher.calls, 2)
-            self.assertEqual(getattr(publisher.samples[0], "name"), 'a' + sfx)
-            self.assertEqual(getattr(publisher.samples[1], "name"), 'b' + sfx)
+            self.assertEqual(2, len(publisher.samples))
+            self.assertEqual(2, publisher.calls)
+            self.assertEqual('a' + sfx, getattr(publisher.samples[0], "name"))
+            self.assertEqual('b' + sfx, getattr(publisher.samples[1], "name"))
 
     def test_multiple_sources_with_single_sink(self):
         self.pipeline_cfg['sources'].append({
@@ -189,23 +196,23 @@ class TestDecoupledPipeline(pipeline_base.BasePipelineTestCase):
         with pipeline_manager.publisher(None) as p:
             p([self.test_counter])
 
-        self.assertEqual(len(pipeline_manager.pipelines), 2)
-        self.assertEqual(str(pipeline_manager.pipelines[0]),
-                         'test_source:test_sink')
-        self.assertEqual(str(pipeline_manager.pipelines[1]),
-                         'second_source:test_sink')
+        self.assertEqual(2, len(pipeline_manager.pipelines))
+        self.assertEqual('test_source:test_sink',
+                         str(pipeline_manager.pipelines[0]))
+        self.assertEqual('second_source:test_sink',
+                         str(pipeline_manager.pipelines[1]))
         test_publisher = pipeline_manager.pipelines[0].publishers[0]
         another_publisher = pipeline_manager.pipelines[1].publishers[0]
         for publisher in [test_publisher, another_publisher]:
-            self.assertEqual(len(publisher.samples), 2)
-            self.assertEqual(publisher.calls, 2)
-            self.assertEqual(getattr(publisher.samples[0], "name"), 'a_update')
-            self.assertEqual(getattr(publisher.samples[1], "name"), 'b_update')
+            self.assertEqual(2, len(publisher.samples))
+            self.assertEqual(2, publisher.calls)
+            self.assertEqual('a_update', getattr(publisher.samples[0], "name"))
+            self.assertEqual('b_update', getattr(publisher.samples[1], "name"))
 
         transformed_samples = self.TransformerClass.samples
-        self.assertEqual(len(transformed_samples), 2)
-        self.assertEqual([getattr(s, 'name') for s in transformed_samples],
-                         ['a', 'b'])
+        self.assertEqual(2, len(transformed_samples))
+        self.assertEqual(['a', 'b'],
+                         [getattr(s, 'name') for s in transformed_samples])
 
     def _do_test_rate_of_change_in_boilerplate_pipeline_cfg(self, index,
                                                             meters, units):
@@ -240,9 +247,65 @@ class TestDecoupledPipeline(pipeline_base.BasePipelineTestCase):
                                                                  meters,
                                                                  units)
 
+    def test_rate_of_change_boilerplate_per_disk_device_read_cfg(self):
+        meters = ('disk.device.read.bytes', 'disk.device.read.requests')
+        units = ('B', 'request')
+        self._do_test_rate_of_change_in_boilerplate_pipeline_cfg(2,
+                                                                 meters,
+                                                                 units)
+
+    def test_rate_of_change_boilerplate_per_disk_device_write_cfg(self):
+        meters = ('disk.device.write.bytes', 'disk.device.write.requests')
+        units = ('B', 'request')
+        self._do_test_rate_of_change_in_boilerplate_pipeline_cfg(2,
+                                                                 meters,
+                                                                 units)
+
     def test_rate_of_change_boilerplate_network_outgoing_cfg(self):
         meters = ('network.outgoing.bytes', 'network.outgoing.packets')
         units = ('B', 'packet')
         self._do_test_rate_of_change_in_boilerplate_pipeline_cfg(3,
                                                                  meters,
                                                                  units)
+
+    def test_duplicated_sinks_names(self):
+        self.pipeline_cfg['sinks'].append({
+            'name': 'test_sink',
+            'publishers': ['except'],
+        })
+        self.assertRaises(pipeline.PipelineException,
+                          pipeline.PipelineManager,
+                          self.pipeline_cfg,
+                          self.transformer_manager)
+
+    def test_specific_instance_type_meter(self):
+        self.pipeline_cfg = [{
+            'name': "test_pipeline",
+            'interval': 5,
+            'meters': ['instance:m1.tiny'],
+            'transformers': [],
+            'publishers': ["test://"],
+        }, ]
+        pipeline_manager = pipeline.PipelineManager(self.pipeline_cfg,
+                                                    self.transformer_manager)
+
+        self.test_counter = sample.Sample(
+            name='instance:m1.tiny',
+            type=self.test_counter.type,
+            volume=self.test_counter.volume,
+            unit=self.test_counter.unit,
+            user_id=self.test_counter.user_id,
+            project_id=self.test_counter.project_id,
+            resource_id=self.test_counter.resource_id,
+            timestamp=self.test_counter.timestamp,
+            resource_metadata=self.test_counter.resource_metadata,
+        )
+
+        with pipeline_manager.publisher(None) as p:
+            p([self.test_counter])
+
+        publisher = pipeline_manager.pipelines[0].publishers[0]
+
+        self.assertEqual(1, len(publisher.samples))
+        self.assertEqual('instance:m1.tiny',
+                         getattr(publisher.samples[0], "name"))
