@@ -2,8 +2,6 @@
 #
 # Copyright 2012 New Dream Network (DreamHost)
 #
-# Author: Doug Hellmann <doug.hellmann@dreamhost.com>
-#
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
 # a copy of the License at
@@ -19,7 +17,7 @@ from __future__ import print_function
 
 import sys
 
-from oslo.config import cfg
+from oslo_config import cfg
 import six
 
 from ceilometer import storage
@@ -53,9 +51,8 @@ def show_resources(db, args):
                     value = totals[0]['max']
                 else:
                     value = totals[0]['sum']
-                print('    %s (%s): %s' % \
-                     (meter['counter_name'], meter['counter_type'],
-                      value))
+                print('    %s (%s): %s' %
+                      (meter['counter_name'], meter['counter_type'], value))
 
 
 def show_total_resources(db, args):
@@ -115,7 +112,7 @@ def main(argv):
     extra_args = cfg.CONF(
         sys.argv[1:],
         # NOTE(dhellmann): Read the configuration file(s) for the
-        #ceilometer collector by default.
+        # ceilometer collector by default.
         default_config_files=['/etc/ceilometer/ceilometer.conf'],
     )
     db = storage.get_connection_from_config(cfg.CONF)
